<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
import {
  getStationListConfig,
  getAuditForm,
  getSupplierTypeListConfig,
} from '@/utils/form-item-config'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/supplier/page',
        editUrl: 'flower/api/supplier/page/update',
        hasNew: false,
        hasDelete: false,
        operationAttrs: {
          width: '200px',
          fixed: 'right',
        },
        beforeOpen: (row, isNew) => {
          if (!isNew) {
            row.districtStr = this.getDistrict(row)
          }
        },
        columns: [
          {
            label: '供应商名称',
            prop: 'name',
            minWidth: '120px',
            fixed: 'left',
          },
          { label: '供应商类型', prop: 'typeName', minWidth: '100px' },
          {
            label: '地区',
            formatter: (row) =>
              `${row.province || ''}${row.city || ''}${row.region || ''}${
                row.address || ''
              }`,
            minWidth: '200px',
          },
          { label: '联系人', prop: 'contactName', minWidth: '100px' },
          { label: '联系方式', prop: 'contactTel', minWidth: '120px' },
          { label: '注册时间', prop: 'createTime', minWidth: '180px' },
          { label: '审核通过时间', prop: 'passTime', minWidth: '180px' },
          { label: '所属集货站', prop: 'stationName', minWidth: '120px' },
          { label: '状态', prop: 'statusStr', minWidth: '100px' },
          {
            label: '是否显示',
            formatter: (row) => (
              <el-switch
                value={row.showed}
                onChange={this.onShownChange.bind(this, row)}
              ></el-switch>
            ),
            minWidth: 120,
            fixed: 'right',
          },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              { label: '供应商名称', id: 'name', type: 'input' },
              { label: '手机号', id: 'tel', type: 'input' },
              {
                label: '申请日期',
                id: 'createDateBeginStr',
                component: 'el-bus-date-range',
                commonFormat: true,
                commonFormatProps: ['createDateBeginStr', 'createDateEndStr'],
                customClass: 'in-bus-form',
              },
              {
                label: '审核状态',
                id: 'status',
                type: 'bus-select-dict',
                el: {
                  code: 'supplier_status',
                  clearable: true,
                  style: 'width:100%',
                },
              },
              {
                ...getStationListConfig(),
                label: '所属集货站',
              },
            ],
          },
        ],
        form: [
          {
            type: 'row',
            span: 12,
            items: [
              {
                label: '供应商名称：',
                id: 'name',
                type: 'input',
                rules: {
                  required: true,
                  message: '请输入供应商名称',
                  trigger: 'blur',
                },
              },
              {
                ...getSupplierTypeListConfig(),
                str: true,
                strKey: 'typeName',
                rules: {
                  required: true,
                  message: '请选择供应商类型',
                },
              },
              {
                label: '供应商头像：',
                id: 'cover',
                type: 'bus-upload',
                el: {
                  listType: 'picture-card',
                  valueType: 'string',
                  limit: 1,
                  limitSize: 2,
                  tipText: '大小不超过2M',
                },
                forceDisabled: true,
                rules: {
                  required: true,
                  message: '请上传供应商头像',
                },
              },
              {
                label: '地区：',
                id: 'province',
                component: 'el-bus-select-area',
                span: 24,
                commonFormat: true,
                commonFormatProps: ['province', 'city', 'region'],
                str: true,
                strKey: 'districtStr',
                rules: { required: true, message: '请选择地区' },
              },
              {
                label: '详细地址：',
                id: 'address',
                type: 'input',
                span: 24,
                rules: {
                  required: true,
                  message: '请输入详细地址',
                  trigger: 'blur',
                },
              },
              {
                label: '联系人：',
                id: 'contactName',
                type: 'input',
                rules: {
                  required: true,
                  message: '请输入联系人',
                  trigger: 'blur',
                },
              },
              {
                label: '联系方式：',
                id: 'contactTel',
                type: 'input',
                rules: {
                  required: true,
                  message: '请输入联系方式',
                  trigger: 'blur',
                },
              },
              {
                ...getStationListConfig(),
                rules: { required: true, message: '请选择所属集货站' },
              },
              {
                label: '店铺简介：',
                id: 'description',
                type: 'input',
                el: {
                  type: 'textarea',
                  rows: 4,
                },
                span: 24,
                rules: {
                  required: true,
                  message: '请输入店铺简介',
                  trigger: 'blur',
                },
              },
              {
                id: 'idcardType',
                type: 'input',
                hidden: () => true,
              },
              {
                label: '身份证正反面：',
                id: 'idCards',
                component: 'el-bus-upload',
                el: {
                  listType: 'picture-card',
                },
                forceDisabled: true,
                commonFormat: true,
                span: 24,
                hidden: (row) => row.idcardType !== '1',
                rules: { required: true, message: '请上传身份证正反面' },
              },
              {
                label: '营业执照：',
                id: 'pictures',
                component: 'el-bus-upload',
                el: {
                  listType: 'picture-card',
                },
                forceDisabled: true,
                commonFormat: true,
                span: 24,
                hidden: (row) => row.idcardType !== '2',
                rules: { required: true, message: '请上传营业执照' },
              },
            ],
          },
          {
            label: '状态：',
            id: 'status',
            type: 'input',
            str: true,
            readonly: true,
            hidden: (row, item, mode) => mode !== 'view',
            span: 24,
          },
          {
            label: '不通过原因：',
            id: 'rejectReason',
            type: 'input',
            el: {
              type: 'textarea',
            },
            readonly: true,
            hidden: (row, item, mode) => mode !== 'view' || row.status !== 'R',
            span: 24,
          },
        ],
        extraButtons: [
          {
            text: '审核',
            show: (row) => row.status === 'U',
            atClick: (row) => {
              row.districtStr = this.getDistrict(row)
              this.$refs.crud.$refs.extraDialog[0].show(row)
              return false
            },
          },
          {
            text: '修改集货站',
            atClick: (row) => {
              this.$refs.crud.$refs.extraDialog[1].show(row)
              return false
            },
          },
        ],
        extraDialogs: [
          {
            title: '审核',
            readonly: true,
            form: getAuditForm(),
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/supplier/audit',
                {
                  method: 'post',
                  data: {
                    ...val,
                    rejectReason: val.auditRejectReason,
                  },
                }
              )
              if (code === 0) {
                this.$message.success('操作成功')
              }
            },
          },
          {
            title: '修改集货站',
            hiddenReverseItems: [],
            form: [
              {
                ...getStationListConfig(),
              },
            ],
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/supplier/change/station',
                {
                  method: 'post',
                  data: val,
                }
              )
              if (code === 0) {
                this.$message.success('操作成功')
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '供应商列表',
    }
  },
  methods: {
    getDistrict(row) {
      return `${row.province || ''}${row.city || ''}${row.region || ''}`
    },
    onShownChange(row, e) {
      const url = 'flower/api/supplier/page/showed'
      const text = e ? '显示' : '隐藏'
      this.$elBusUtil
        .confirm(`确定要${text}这个供应商的商品吗？`)
        .then(async () => {
          const { code } = await this.$elBusHttp.request(url, {
            params: {
              id: row.id,
            },
          })
          if (code === 0) {
            this.$message.success(`${text}成功`)
            this.$refs.crud.getList()
          }
        })
        .catch(() => {})
    },
  },
}
</script>
